#
# spec file for package cinnamon-desktop
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname  libcinnamon-desktop
%define sover   4
%define soname_cvc libcvc
%define sover_cvc 0
%define typelib typelib-1_0-CinnamonDesktop-3_0
%define typelib_cvc typelib-1_0-Cvc-1_0
Name:           cinnamon-desktop
Version:        6.0.0
Release:        2.1
Summary:        Libcinnamon-desktop API
License:        GPL-2.0-or-later AND MIT
Group:          System/GUI/Other
URL:            https://github.com/linuxmint/cinnamon-desktop
Source:         https://github.com/linuxmint/%{name}/archive/%{version}/%{name}-%{version}.tar.gz
# Some documentation for people writing branding packages, shipped in the branding-upstream package.
Source1:        README.Gsettings-overrides
Source2:        baselibs.conf
# PATCH-FIX-OPENSUSE cinnamon-desktop-correct-background-path.patch sor.alexi@meowr.ru -- Fix path to Adwaita background.
Patch0:         %{name}-correct-background-path.patch
BuildRequires:  intltool
BuildRequires:  meson
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(accountsservice)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0) >= 2.22.0
BuildRequires:  pkgconfig(gio-2.0) >= 2.37.3
BuildRequires:  pkgconfig(glib-2.0) >= 2.37.3
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 0.9.7
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.10.0
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libpulse-mainloop-glib)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(xext) >= 1.1
BuildRequires:  pkgconfig(xkbfile)
BuildRequires:  pkgconfig(xkeyboard-config)
BuildRequires:  pkgconfig(xrandr) >= 1.3

%description
cinnamon-desktop contains the libcinnamon-desktop library, the
cinnamon-about program as well as some desktop-wide documents.

The libcinnamon-desktop library provides API shared by several
applications on the desktop, but that cannot live in the platform
for various reasons. There is no API or ABI guarantee, although we
are doing our best to provide stability. Documentation for the API
is available with gtk-doc.

%package -n %{soname}%{sover}
Summary:        Libcinnamon-desktop API
Group:          System/Libraries
Requires:       %{soname}-data >= %{version}
Provides:       %{name} = %{version}
Provides:       %{soname} = %{version}
Obsoletes:      %{name} < %{version}

%description -n %{soname}%{sover}
cinnamon-desktop contains the libcinnamon-desktop library, the
cinnamon-about program as well as some desktop-wide documents.

The libcinnamon-desktop library provides API shared by several
applications on the desktop, but that cannot live in the platform
for various reasons. There is no API or ABI guarantee, although we
are doing our best to provide stability. Documentation for the API
is available with gtk-doc.

%lang_package -n %{soname}

%package -n %{soname}-data
Summary:        Libcinnamon-desktop API -- Common Files
Group:          System/GUI/Other
Requires:       %{soname}-data-branding = %{version}
Requires:       pam
Requires:       python3-gobject
Recommends:     %{soname}-lang
# cinnamon-desktop-lang was last used in openSUSE 13.2.
Provides:       %{name}-lang = %{version}
Obsoletes:      %{name}-lang < %{version}
BuildArch:      noarch
%glib2_gsettings_schema_requires

%description -n %{soname}-data
cinnamon-desktop contains the libcinnamon-desktop library, the
cinnamon-about program as well as some desktop-wide documents.

This package includes files that are shared between several
Cinnamon applications (configuration schemas).

%package -n %{soname}-data-branding-upstream
Summary:        Upstream definitions of default settings and applications
Group:          System/GUI/Other
Requires:       %{soname}-data = %{version}
Requires:       gnome-backgrounds
Requires:       metatheme-adwaita-common
Supplements:    (%{soname}-data and branding-upstream)
Conflicts:      %{soname}-data-branding
Provides:       %{soname}-data-branding = %{version}
BuildArch:      noarch
#BRAND: A /usr/share/glib-2.0/schemas/$NAME.gschema.override file can
#BRAND: be used to override the default value for GSettings keys. See
#BRAND: README.Gsettings-overrides for more details. The branding
#BRAND: package should then have proper Requires for features changed
#BRAND: with such an override file.

%description -n %{soname}-data-branding-upstream
This package provides upstream defaults for settings stored with
GSettings and applications used by the MIME system.

%package -n %{typelib}
Summary:        Libcinnamon-desktop API -- Introspection bindings
Group:          System/Libraries

%description -n %{typelib}
cinnamon-desktop contains the libcinnamon-desktop library, the
cinnamon-about program as well as some desktop-wide documents.

This package provides the GObject Introspection bindings for
libcinnamon-desktop.

%package -n %{soname}-devel
Summary:        Libcinnamon-desktop API -- Development Files
Group:          Development/Libraries/C and C++
Requires:       %{soname}%{sover} = %{version}
Requires:       %{typelib} = %{version}
Requires:       pkgconfig
Requires:       pkgconfig(gtk+-3.0)
Requires:       pkgconfig(xkbfile)
# cinnamon-desktop-devel was last used in openSUSE 12.3.
Provides:       %{name}-devel = %{version}
Obsoletes:      %{name}-devel < %{version}

%description -n %{soname}-devel
cinnamon-desktop contains the libcinnamon-desktop library, the
cinnamon-about program as well as some desktop-wide documents.

This package contains development files for libcinnamon-desktop.

%package -n %{soname_cvc}%{sover_cvc}
Summary:        LibCVC API
Group:          System/Libraries

%description -n %{soname_cvc}%{sover_cvc}
Utility library for volume control of pulseaudio from gobject-based
Cinnamon modules/applications.

%package -n %{typelib_cvc}
Summary:        LibCVC API -- Introspection bindings
Group:          System/Libraries

%description -n %{typelib_cvc}
Utility library for volume control of pulseaudio from gobject-based
Cinnamon modules/applications.

This package provides the GObject Introspection bindings for libcvc.

%package -n %{soname_cvc}-devel
Summary:        LibCVC API -- Development Files
Group:          Development/Libraries/C and C++
Requires:       %{soname_cvc}%{sover_cvc} = %{version}
Requires:       %{typelib_cvc} = %{version}
Requires:       pkgconfig
Requires:       pkgconfig(libpulse)
Requires:       pkgconfig(libpulse-mainloop-glib)

%description -n %{soname_cvc}-devel
Utility library for volume control of pulseaudio from gobject-based
Cinnamon modules/applications.

This package contains development files for libcvc.

%prep
%autosetup -p1

cp -a %{SOURCE1} .

%build
%if 0%{?suse_version} < 1500
mkdir -p bin
cat > bin/g-ir-scanner << EOF
#!/bin/sh
# This breaks the build. There are also useless entries in shared-library= in
# .gir files but that doesn't seem to have any actual implications here.
export SUSE_ASNEEDED=0
exec %{_bindir}/g-ir-scanner "\$%{nil}@"
EOF
chmod a+x bin/g-ir-scanner

export PATH="$PWD/bin:$PATH"
%endif
%meson
%meson_build

%install
%meson_install
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name} %{?no_lang_C}

%if 0%{?suse_version} < 1500
%post -n %{soname}-data
%glib2_gsettings_schema_post

%postun -n %{soname}-data
%glib2_gsettings_schema_postun
%endif

%post -n %{soname}%{sover} -p /sbin/ldconfig

%postun -n %{soname}%{sover} -p /sbin/ldconfig

%post -n %{soname_cvc}%{sover_cvc} -p /sbin/ldconfig

%postun -n %{soname_cvc}%{sover_cvc} -p /sbin/ldconfig

%files -n %{soname}%{sover}
%license COPYING*
%doc AUTHORS README debian/changelog
%{_libdir}/%{soname}.so.%{sover}*

%files -n %{soname}-lang -f %{name}.lang

%files -n %{soname}-data
%license COPYING*
%doc AUTHORS README debian/changelog
#%%{_bindir}/cinnamon-desktop-migrate-mediakeys
%{_datadir}/glib-2.0/schemas/*.xml
%{_datadir}/%{soname}/

%files -n %{soname}-data-branding-upstream
%doc README.Gsettings-overrides

%files -n %{typelib}
%{_libdir}/girepository-1.0/CinnamonDesktop-3.0.typelib
%{_libdir}/girepository-1.0/CDesktopEnums-3.0.typelib

%files -n %{soname}-devel
%{_includedir}/%{name}/
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/%{soname}.so
%{_datadir}/gir-1.0/CinnamonDesktop-3.0.gir
%{_datadir}/gir-1.0/CDesktopEnums-3.0.gir

%files -n %{soname_cvc}%{sover_cvc}
%license COPYING*
%doc AUTHORS README debian/changelog
%{_libdir}/%{soname_cvc}.so.%{sover_cvc}*

%files -n %{typelib_cvc}
%{_libdir}/girepository-1.0/Cvc-1.0.typelib

%files -n %{soname_cvc}-devel
%{_libdir}/pkgconfig/cvc.pc
%{_libdir}/%{soname_cvc}.so
%{_datadir}/gir-1.0/Cvc-1.0.gir

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Sat Nov 25 2023 Dirk Müller <dmueller@suse.com>
- update to 6.0.0:
  * gschemas: Change a comment
  * Fix meson.build deprecations up to 0.56.0
  * cdesktop-enums: Expand CDesktopStylusButtonAction to include
    'disabled'.
  * Add gnome-systemd
  * Add gnome-idle-monitor
  * a11y: Add 'always-show-text-caret' xsetting
  * Adding an option for notification screen selection
  * notifications schema: Add fullscreen-notifications boolean
* Fri Jun  2 2023 Dirk Müller <dmueller@suse.com>
- updaet to 5.8.0:
  * Add high-contrast key.
  * gnome-desktop-thumbnailer.c: Only attempt to thumbnail
    internally if gdk-pixbuf actually supports the mime_type.
  * org.cinnamon.desktop.keybindings: Add entries for warping the
    pointer between monitors.
  * Remove color-scheme additions (added in d880133b38da46b22).
  * Update cvc symbols.
* Sun Apr 16 2023 Dirk Müller <dmueller@suse.com>
- update to 5.6.2:
  * gnome-desktop-thumbnail.c: Use g_get_user_cache_dir() for
    thumbnail permission checks.
  * gnome-desktop-thumbnailer.c: Only attempt to thumbnail
    internally if gdk-pixbuf actually supports the mime_type.
* Sat Jan 28 2023 Dirk Müller <dmueller@suse.com>
- update to 5.6.1:
  * Add a settings key for the gtk-enable-primary-paste GtkSetting.
  * touchpad: Enable tap-to-click by default.
* Tue Dec  6 2022 Aaron Stern <ukbeast89@protonmail.com>
- Remove (fix_return_value_void.patch) as it's no longer needed.
* Tue Dec  6 2022 Aaron Stern <ukbeast89@protonmail.com>
- Update to 5.6.0.
  * Fix some introspection problems.
  * Use github instead of circleci.
  * Keybindings: Add a default keybinding for 'switch-panels-backward'.
  * gvc-channel-map.c: Fix return with a value in a void function.
  * gnome-wall-clock.c: Fix a gi scanner warning.
  * fix a null pointer deref scan-build found.
  * Add a setting for notification duration.
* Fri Nov 11 2022 andy great <andythe_great@pm.me>
- Update to 5.4.7.
  * libcvc: Add stream monitor functionality
- Update for 5.4.1
  * libcvc/meson.build: fix building with alsa. (#207)
  * Fix testsound positions in cinnamon-settings
- Update for 5.4.0
  * Add debian/ symbol files for libcvc and libcinnamon-desktop.
  * d/control: update build-deps
  * Refresh Cvc
  * all: Changes for muffin rebase
  * Fix build warnings
  * CI: Update targets
- Update for 5.2.1
  * gnome-desktop-thumbnailer.c: Make sure a thumbnailer's binary is found in the path before deciding to use it.
- Update for 5.2.0
  * Add screen reader keybinding for improve accessibility
  * gnome-rr.c: Restore fractional scale limiting, mistakenly removed in 23b8dcf6bb14fc625d.
  * Allow 3x scaling if the monitor resolution safely permits it.
  * build: don't translate gschemas (#200)
- Add patch, fix_return_value_void.patch.
- Rebase cinnamon-desktop-correct-background-path.patch.
* Thu May 27 2021 andy great <andythe_great@pm.me>
- Update to version 5.0.0.
  * avoid deprecated g_type_class_add_private
  * libcinnamon-desktop: Fix some various build warnings, and an
    incorrect free.
  * gnome-bg.c: fix a leak
    https://gitlab.gnome.org/GNOME/gnome-desktop/-/commit/af0f0fbb835e5bb22b7bce4581d3f081462b5f5b
    and another similar instance
  * Always parse date/time integers in base-10
* Tue Dec  8 2020 andy great <andythe_great@pm.me>
- Update to version 4.8.1.
  * gnome-bg.c: don't decrement hour by 1 when parsing xml
    backgrounds
- Updates for version 4.8.0
  * cdesktop-enums.h: Don't allow area or window screenshots while
    cinnamon is in a grab state
  * debian: Bump debhelper compat level to 12
  * small improves to debian/copyright
  * gnome-rr-config.c: Remove some unused variables
  * Default terminal: Change exec-arg from '-x' to '--'
* Sun Sep 13 2020 andy great <andythe_great@pm.me>
- Update to version 4.6.4.
  * gnome-rr.c: Only use nearest filtering for "pixel-exact"
    scaling, not any whole integer scale.
  * gnome-rr-config.c: Don't ignore disabled monitors when shifting
    the layout towards 0,0.
* Thu Jun 11 2020 Aaron Stern <ukbeast89@protonmail.com>
- update version 4.6.1
  * CI: Use specific job tags
  * use debhelper 11 for integrated meson support
  * CI: Target Mint 20 and LMDE 4
* Mon Mar 16 2020 Marguerite Su <i@marguerite.su>
- update version 4.4.1
  * Clock: Fix date format when LC_TIME and LANGUAGE are the same,
    or LC_TIME is NULL
- changes in 4.4.0
  * org.cinnamon.desktop.session schema: Remove logind/consolekit
    settings
  * Fetch clock formats using LC_TIME (as opposed to LANGUAGE)
  * Fix unused GIR transfer notation on integer values
* Sun Jul 21 2019 Marguerite Su <i@marguerite.su>
- Update to version 4.2.0
  * gnome-wall-clock.c: Fix memory leak when a custom format
    string is in use.
  * Privacy: Enable recents by default
  * Remove legacy migration script from cinnamon 2.4
* Wed Mar 13 2019 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 4.0.1:
  * gnome-wall-clock.c: Fix memory leak when a custom format string is.
  * Updated slovak translation - translated new strings(100%%), fixed date/time format
  * Update for meson changes
  * Following the review of docinfo, this should be enabled by default.
* Tue May  8 2018 sor.alexei@meowr.ru
- Update to version 3.8.1:
  * Add key binding setting for showing desklets.
  * Fix pkgconfig version and fix spacing.
* Thu Apr 19 2018 sor.alexei@meowr.ru
- Update to version 3.8.0:
  * Switch to Meson.
  * gnome-wall-clock.c: Adjust DATE_ONLY msgid to match the one
    originally in cinnamon-screensaver, and graft in existing
    translations from cinnamon-screensaver 3.2.2.
  * gnome-wall-clock.c: Add some comments for translators for our
    date formats.
  * Remove gsettings key org.cinnamon.desktop.interface
    gtk-decoration-layout.
  * Add a setting for maximum sound volume.
  * Remove libgsystem.
  * Fix AccountsService set_background check.
  * Make alsa support opt-in.
  * libcvc: Fix pc version.
  * libcinnamon-desktop: Fix enum generation.
  * gnome-bg.c: Add support for setting the user background via
    org.freedesktop.DisplayManager.AccountsService, whilst
    retaining support for the old method (for ubuntu 16.04)
  * gnome-bg.c: Fix SetBackgroundFile call - parameters must be a
    GVariant tuple.
  * Notifications: Add bottom position option.
  * gnome-bg: Don't unref NULL gvariant.
  * gnome-bg: Proper fix for NULL gvariant unref.
* Sun Nov 12 2017 sor.alexei@meowr.ru
- Update to version 3.6.2:
  * Set org.cinnamon.desktop.screensaver ask-for-away-message to
    False.
* Thu Nov  9 2017 sor.alexei@meowr.ru
- Update to version 3.6.1:
  * Default: Change idle-delay default to 15 min.
  * Remove obsolete gsettings key.
* Sat Oct 28 2017 sor.alexei@meowr.ru
- Update to version 3.6.0:
  * gnome-wall-clock: Improve API, handle seconds timing based on
    format string.
  * Use logind by default.
  * Use Python3 instead of Python2.
* Wed Jun 21 2017 sor.alexei@meowr.ru
- Update to version 3.4.2:
  * gnome-wall-clock: Add functionality to allow setting the update
    interval.
* Wed May 24 2017 sor.alexei@meowr.ru
- Update to version 3.4.1:
  * gnome-desktop-thumbnail: Add EFAULT as an exception to the
    permission check.
    See https://github.com/linuxmint/nemo/commit/b58bea5
* Thu May  4 2017 sor.alexei@meowr.ru
- Update to version 3.4.0:
  * schemas: Add some new keys for High Contrast.
  * gvc-mixer-control: fix double-free when setting headset
    https://git.gnome.org/browse/libgnome-volume-control/commit/?id=a28e23d
    https://git.gnome.org/browse/libgnome-volume-control/commit/?id=25bf3ed
  * gvc-mixer-control: Fix reference being leaked
    https://git.gnome.org/browse/libgnome-volume-control/commit/?id=d52194f
  * Add detection for accountsservice background as it's Ubuntu
    only.
  * Remove aclocal from autogen.sh.
* Thu Dec 15 2016 sor.alexei@meowr.ru
- Update to version 3.2.4 (changes since 3.2.1):
  * Remove PAM authentication - this is moved back to
    cinnamon-screensaver, the only current user.
  * media-keys: Add Rotation lock support.
  * screensaver schema: Add floating widget preference.
  * Privacy: Disable tracking of recent files by default.
- Remove cinnamon-desktop-suse-pam.patch.
* Thu Nov 24 2016 sor.alexei@meowr.ru
- Update to version 3.2.1:
  * Update PAM for Fedora selinux
  * Fix includes for libcvc
  * Port some PAM code from cinnamon-screensaver 3.0:
  - Don't check return value of pam_acct_mgmt.
    On some systems it can fail because account modules are not
    configured properly or because this check requires
    additional privileges.
  - Call pam_setcred() to refresh credentials.
- Rebase cinnamon-desktop-suse-pam.patch.
* Tue Nov  8 2016 sor.alexei@meowr.ru
- Update to version 3.2.0:
  * Migrate away from gnome-common deprecated vars and macros.
  * gnome-bg: Add an introspectable method to GnomeBG to allow
    setting a GtkImage with a background surface.
  * gnome-bg.c: Use gdk_cairo_surface_create_from_pixbuf() for
    creating GtkImage surfaces - this handles widget scale factors
    for us, and gives back the correct size/scale image surface.
  * gnome-desktop-utils: Add a pam password check function.
  * Add /etc/pam.d/cinnamon-desktop to build and packaging to allow
    authentication to work.
  * screensaver schema: Add flag, keyboard layout, and clock
    visiblity keys.
  * Make AX_ macros optional.
  * screensaver schema: Add caps keyboard layout option.
  * screensaver schema: Add albumart preference.
  * gnome-desktop-thumbnail.c: Remove hardcoded GdkPixbuf blacklist,
    and make mimetypes in the "disable" gsettings key apply to the
    entire thumbnail factory, not just pluggable thumbnailers.
  * Move flag, uppercase prefs from screensaver to interface
    schema, and add a preference for layout name.
  * Add screensaver lockdown preferences.
- Add cinnamon-desktop-suse-pam.patch: Use SUSE-specific PAM
  configuration.
- Create libcinnamon-desktop-data-branding:
  libcinnamon-desktop-data has to have an independent from the main
  cinnamon package branding.
* Sun May 22 2016 sor.alexei@meowr.ru
- Update to version 3.0.2:
  * libcvc: Update doap file.
  * org.cinnamon.desktop.interface schema: Add setting for gtk
    overlay scrollbars.
  * Backgrounds: Take EXIF rotation tags into consideration.
* Thu May 12 2016 sor.alexei@meowr.ru
- Update to version 3.0.1:
  * Fix possible null pointer dereference.
  * Fix usage of uninitialised values.
  * Disable event-sounds by default.
  * Disable audible-bell by default.
  * Remove dependency on gnome-software (boo#978264).
* Wed May  4 2016 sor.alexei@meowr.ru
- Add a missing python-gobject-Gdk dependency (boo#978298).
* Mon Apr 25 2016 sor.alexei@meowr.ru
- Update to version 3.0.0:
  * a11y schema: Limit desktop zoom max magnification to 15x.
  * Add installer functions to check and install packages via
    PackageKit.
  * enums: Add zoom lens shape enum and magnifier key.
  * gnome-installer: Use a GTask for the IsInstalled loop, so the
    main thread isn't blocked. Add some feedback to the test script
    to check this.
  * Schemas: Add a few keys for a11y stuff.
  * Add libcvc source and packages to build.
  * gvc-channel-map.h: Add missing include.
  * gvc-channel-map.c: Remove redundant include.
  * thumbnail: Fix a code path where the mutex is never unlocked.
  * Some fixes for introspection.
  * gvc_mixer_ui_device.c: Fix comment block causing a build
    warning.
- Add gnome-software (gnome-packagekit-session) dependency to
  libcinnamon-desktop package as did upstream.
* Wed Mar  9 2016 sor.alexei@meowr.ru
- Update to 2.8.1:
  * a11y schema: Limit desktop zoom max magnification to 15x.
  * thumbnail: Fix a code path where the mutex is never unlocked.
* Sun Oct 18 2015 sor.alexei@meowr.ru
- Update to 2.8.0:
  * Make cinnamon-desktop buildable with make.
  * gnome-desktop-thumbnailer.c: block known-buggy image types from
    being thumbnailed.
  * Create keybinding for XF86AudioMicMute => mic-mute.
  * Fix xml bg warning.
- Separate library data to libcinnamon-desktop-data package.
- Add cinnamon-desktop-correct-background-path.patch.
- Spec cleanup.
* Mon Aug 10 2015 i@marguerite.su
- update version 2.6.5
  * screensaver schemas: use a default value that exists
  * ignore X errors when applying xrandr configuration
- add baselibs.conf
* Tue Jun  2 2015 stefan@fam-elser.de
- update to version 2.6.4
* Thu Apr 23 2015 stefan@fam-elser.de
- update to version 2.4.2
* Mon Nov 10 2014 i@marguerite.su
- update version 2.4.1
  * changed checking for NULL a bit
  * keybinding migration script: add run-once check
  * Remove postinst script for keybindings
* Wed Nov  5 2014 i@marguerite.su
- update version 2.4.0
* Mon Jul 14 2014 i@marguerite.su
- update version 2.3.0
  * upstream just bump its version
* Wed May 21 2014 stefan@fam-elser.de
- update version 2.2.3
* Mon May 19 2014 stefan@fam-elser.de
- update version 2.2.2
* Thu Apr 17 2014 i@marguerite.su
- update version 2.2.0
- fix libcinnamon-desktop-lang requires libcinnamon-desktop problem
* Mon Nov 25 2013 johann.luce@wanadoo.fr
- update version 2.0.4
  * thumbnailer: Handle empty image files without crashing
* Mon Nov  4 2013 johann.luce@wanadoo.fr
- update version 2.0.3
  * remove a leftover from copying autogen.sh from nemo
  * Add new gi method for javascript background
* Mon Oct 28 2013 i@marguerite.su
- update version 2.0.2
  * fix some schema names
* Mon Oct 21 2013 i@marguerite.su
- rename libcinnamon-desktop, it's a library
* Mon Oct 21 2013 i@marguerite.su
- copypac from home:cyberorg:cinnamon
- add typelib-1_0-CinnamonDesktop-3_0 subpackage
- some clean
* Thu Oct 10 2013 stefan@fam-elser.de
- Updated to version 2.0.2
* Wed Oct  2 2013 stefan@fam-elser.de
- Initial release with git files from 2013/09/30
